==> huaweicloudsdkcodeartscheck-3.1.94-py2.py3-none-any.whl: huaweicloudsdkcodeartscheck/v2/model/update_task_ruleset_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateTaskRulesetRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'task_id': 'str',
        'body': 'list[UpdateTaskRulesetItem]'
    }

    attribute_map = {
        'task_id': 'task_id',
        'body': 'body'
    }

    def __init__(self, task_id=None, body=None):
        """UpdateTaskRulesetRequest

        The model defined in huaweicloud sdk

        :param task_id: 任务ID
        :type task_id: str
        :param body: 修改任务规则集
        :type body: list[:class:`huaweicloudsdkcodeartscheck.v2.UpdateTaskRulesetItem`]
        """
        
        

        self._task_id = None
        self._body = None
        self.discriminator = None

        self.task_id = task_id
        if body is not None:
            self.body = body

    @property
    def task_id(self):
        """Gets the task_id of this UpdateTaskRulesetRequest.

        任务ID

        :return: The task_id of this UpdateTaskRulesetRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this UpdateTaskRulesetRequest.

        任务ID

        :param task_id: The task_id of this UpdateTaskRulesetRequest.
        :type task_id: str
        """
        self._task_id = task_id

    @property
    def body(self):
        """Gets the body of this UpdateTaskRulesetRequest.

        修改任务规则集

        :return: The body of this UpdateTaskRulesetRequest.
        :rtype: list[:class:`huaweicloudsdkcodeartscheck.v2.UpdateTaskRulesetItem`]
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateTaskRulesetRequest.

        修改任务规则集

        :param body: The body of this UpdateTaskRulesetRequest.
        :type body: list[:class:`huaweicloudsdkcodeartscheck.v2.UpdateTaskRulesetItem`]
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateTaskRulesetRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartscheck-3.1.145-py2.py3-none-any.whl: huaweicloudsdkcodeartscheck/v2/model/update_task_ruleset_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateTaskRulesetRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'task_id': 'str',
        'body': 'list[UpdateTaskRulesetItem]'
    }

    attribute_map = {
        'task_id': 'task_id',
        'body': 'body'
    }

    def __init__(self, task_id=None, body=None):
        r"""UpdateTaskRulesetRequest

        The model defined in huaweicloud sdk

        :param task_id: 任务ID
        :type task_id: str
        :param body: 修改任务规则集
        :type body: list[:class:`huaweicloudsdkcodeartscheck.v2.UpdateTaskRulesetItem`]
        """
        
        

        self._task_id = None
        self._body = None
        self.discriminator = None

        self.task_id = task_id
        if body is not None:
            self.body = body

    @property
    def task_id(self):
        r"""Gets the task_id of this UpdateTaskRulesetRequest.

        任务ID

        :return: The task_id of this UpdateTaskRulesetRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        r"""Sets the task_id of this UpdateTaskRulesetRequest.

        任务ID

        :param task_id: The task_id of this UpdateTaskRulesetRequest.
        :type task_id: str
        """
        self._task_id = task_id

    @property
    def body(self):
        r"""Gets the body of this UpdateTaskRulesetRequest.

        修改任务规则集

        :return: The body of this UpdateTaskRulesetRequest.
        :rtype: list[:class:`huaweicloudsdkcodeartscheck.v2.UpdateTaskRulesetItem`]
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateTaskRulesetRequest.

        修改任务规则集

        :param body: The body of this UpdateTaskRulesetRequest.
        :type body: list[:class:`huaweicloudsdkcodeartscheck.v2.UpdateTaskRulesetItem`]
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateTaskRulesetRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
